@@ -4,7 +4,7 @@ DISTRIB="$1"
 TDE_VERSION="$2"
 ARCH="$3"
 
-[ -z "${TDE_VERSION}" ] && TDE_VERSION="14.0.12"
+[ -z "${TDE_VERSION}" ] && TDE_VERSION="14.1.0"
 [ -z "${ARCH}" ] && ARCH="x86_64"
 [ -x /usr/bin/podman ] && DOCKER=podman || DOCKER=docker
 
@@ -31,7 +31,7 @@ ${DOCKER} run -ti --rm \
   -e TMPPATH=/tmp \
   -e TDE_VERSION=${TDE_VERSION} \
   -e TDE_BRANCH=${TDE_BRANCH} \
-  -w /home/trinity/tde/${TDE_BRANCH}/tde-packaging/redhat \
+  -w /home/trinity/tde/${TDE_BRANCH}/tde/packaging/redhat \
   -v ${HOME}/.gnupg:/home/trinity/.gnupg \
   -v ${HOME}/tde/master:/home/trinity/tde/master \
   -v ${HOME}/tde/r14.0.x:/home/trinity/tde/r14.0.x \
